import { CollectionConfig } from 'payload/types';

const Dispatches: CollectionConfig = {
  slug: 'dispatches',
  admin: {
    useAsTitle: 'dispatchesCode',
  },
  access: {
    read: () => true,
  },
  fields: [
    {
        name: 'dispatchesCode',
        type: 'text', 
        required: true,
      },
      {
        name: 'products', 
        type: 'relationship', 
        relationTo: 'products', 
        hasMany: true,
      },
      {
        name: 'startingPoint', 
        type: 'relationship', 
        relationTo: 'makers', 
        hasMany: false,
      },
      {
        name: 'endPoint', 
        type: 'relationship', 
        relationTo: 'retailers', 
        hasMany: false,
      },
      {
        name: 'typeOfTransportation',
        type: 'select',
        hasMany: true,
        options: [
          {
            label: 'Air',
            value: 'air'
          },
          {
            label: 'Car',
            value: 'car'
          },
          {
            label: 'Train',
            value: 'train'
          },
          {
            label: 'Boat',
            value: 'boat'
          }
        ]
      },
      {
        name: 'courier', 
        type: 'relationship', 
        relationTo: 'couriers', 
        hasMany: false,
      },
      {
        name: 'timeSensitive', 
        type: 'checkbox', 
      },
      {
        name: 'status', // required
        type: 'select', // required
        hasMany: true,
        // admin: {
        //   isClearable: true,
        //   isSortable: true, // use mouse to drag and drop different values, and sort them according to your choice
        // },
        options: [
          {
            label: 'Route requested',
            value: 'routeRequested',
          },
          {
            label: 'In transit',
            value: 'inTransit',
          },
          {
            label: 'Completed',
            value: 'completed',
          },
        ],
      }
  ],
};

export default Dispatches;